"""
:mod:`libertine` -- bindings for the Libertine application sandbox
==================================================================

.. module:: libertine
   :synopsis: A sandbox for running DEB-packaged X11-based applications
"""

# Copyright 2015 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

__all__ = [
          # from Libertine
          'LibertineApplication',
          'LibertineContainer',
          'LibertineSessionBridge',
          'LibertineSessionBridge',
          'HostSessionSocketPair',
          'SessionSocket',
          'Socket',
          'utils',
          ]

__docformat__ = "restructuredtext en"

from libertine.Libertine import LibertineApplication
from libertine.Libertine import LibertineContainer
from libertine.Libertine import LibertineSessionBridge
from libertine.Libertine import HostSessionSocketPair
from libertine.Libertine import SessionSocket
from libertine.Libertine import Socket
